% This script demonstrates the fitting of parameters of the Self
% Similar Rayleigh Gans Approximation on simulated aggregates provided
% by Jani Tyynela.

% Load Araw functions for randomly oriented aggregates of around 8 mm
% in maximum dimension, as well as the actual maximum dimensions Dmax
% and dipole spacing dipole_dx.
load tyynela_data_8mm.mat

nominal_size = 8e-3; % m

clf
set(gcf,'defaultaxesfontsize',7);
set(gcf,'defaultlinelinewidth',0.5);

% Specify the slope of the power spectrum
gamma = 2;

% Compute SSRGA fitting parameters
ssrga_params = fit_ssrga_params(Dmax, Araw, dipole_dx, gamma)

% Plot shape
subplot(2,2,1)
plot_normalized_shape(ssrga_params);
title(['\bf(a) D_{max} = ' num2str(nominal_size.*1000) ' mm']);

% Plot power spectrum
subplot(2,2,2);
plot_spectrum(ssrga_params);
title(['\bf(b) D_{max} = ' num2str(nominal_size.*1000) ' mm']);

