function bcs = rayleigh(wavelength, dielectric_const, volume)
%RAYLEIGH
%   Compute the backscatter cross section of an particle using the
%   Rayleigh approximation
%
%   bcs = rayleigh(wavelength, dielectric_const, volume)
%
%   where the arguments are:
%     bcs                  Backscatter cross-section (m2)
%     wavelength           Wavelength of radiation (m)
%     dielectric_const     Dielectric constant of material (complex)
%     volume               Volume of material (m3)
%
%   This file was written by Robin Hogan, but no copyright is asserted: this
%   file is in the public domain.  Therefore, copying and distribution of
%   this file, with or without modification, and merging all or part of this
%   file into other works, are permitted in any medium without royalty.
%   This file is offered as-is, without any warranty.

% Dielectric factor
K2 = abs(((dielectric_const-1)./(dielectric_const+2))).^2;

% Wavenumber
k = 2.*pi./wavelength;

% Compute backscatter cross section
bcs = 9.*volume.^2.*K2.*k.^4./(4.*pi);

